The tools in this module are used to define a subspace in some higher dimensional space.  As discussed in the papers cited below 
this subspace can be a defined using a set of linear projections from the high dimensional space to some lower dimensional linear 
space or it can be a curilinear path or curvilinear manifold.  Furthermore, the high dimensional space can describe the positions of 
all or a subset of the atoms in your system or it can be defined using a large number of collective variables. 
